Struct
QmiMessageWdsBindSubscriptionOutput
since: 1.37
Description [src]
struct QmiMessageWdsBindSubscriptionOutput {
/* No available fields */
}
The QmiMessageWdsBindSubscriptionOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.37
Instance methods
qmi_message_wds_bind_subscription_output_get_result
Get the result of the QMI operation.
since: 1.37
qmi_message_wds_bind_subscription_output_ref
Atomically increments the reference count of self by one.
since: 1.37
qmi_message_wds_bind_subscription_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.37